from django.core.management.base import BaseCommand, CommandError
import os
import tornado
import tornado.httpserver
import tornado.ioloop
import tornado.wsgi
from django.core.wsgi import get_wsgi_application
from dj_static import Cling, MediaCling


class Command(BaseCommand):
    help = '''runs your application in tornado's HTTPServer'''

    def handle(self, *args, **kwargs):
        # Bind to PORT if defined, otherwise default to 5000.
        port = int(os.environ.get('PORT', 5000))
        application = Cling(get_wsgi_application())
        container = tornado.wsgi.WSGIContainer(application)
        http_server = tornado.httpserver.HTTPServer(container)
        http_server.listen(port)
        try:
            tornado.ioloop.IOLoop.instance().start()
        except KeyboardInterrupt:
            raise CommandError('Terminating server on request')





from __future__ import unicode_literals
from setuptools import setup, find_packages
import os

import dj_tornado

here = os.path.dirname(__file__) 

version = ".".join(map(str, dj_tornado.__version__))
author_first, author_last, author_email = dj_tornado.__author__.split()
author = " ".join((author_first, author_last))
author_email = author_email.strip('<>')
description = dj_tornado.__doc__
README = open(os.path.join(here, 'README.md')).read()
install_requires = ['tornado', 'dj-static']

setup(name='dj-tornado',
      version=version,
      description=description,
      long_description=README,
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Information Technology',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 3',
          'Topic :: Software Development :: Libraries :: Python Modules',
          'Topic :: Utilities',
          'License :: OSI Approved :: MIT License',
          'Framework :: Django'
      ],
      keywords='django in tornado as management command',
      author=author,
      author_email=author_email,
      url='http://github.com/weargoggles/django-tornado',
      license='MIT License',
      packages=find_packages(),
      include_package_data=True,
      test_suite='dj_tornado.tests',
      zip_safe=False,
      install_requires=install_requires,
)
